import { Module } from "@nestjs/common";
import { ConfigModule, ConfigService } from "@nestjs/config";
import { ThrottlerModule } from "@nestjs/throttler";
import { AuthModule } from "./auth/auth.module";
import { CredentialsModule } from "./credentials/credentials.module";
import { DrizzleModule } from "./drizzle/drizzle.module";
import { LogService } from "./logger/logger.service";
import { ProductsModule } from './products/products.module';
import { StocksModule } from './stocks/stocks.module';
import { TransactionsModule } from './transactions/transactions.module';

@Module({
	imports: [
		ThrottlerModule.forRoot([
			{
				ttl: 60000,
				limit: 10,
			},
		]),
		ConfigModule.forRoot({
			isGlobal: true,
		}),
		DrizzleModule,
		AuthModule,
		CredentialsModule,
		ProductsModule,
		StocksModule,
		TransactionsModule,
	],
	exports: [LogService],
	controllers: [],
	providers: [LogService],
})
export class AppModule {}
