import {
	IsEmail,
	IsNotEmpty,
	IsString,
	IsStrongPassword,
	MaxLength,
	MinLength,
} from "class-validator";

export class SignUpDto {
	@MinLength(1)
	@MaxLength(24)
	@IsNotEmpty()
	@IsString()
	firstName: string;

	@MinLength(1)
	@MaxLength(24)
	@IsNotEmpty()
	@IsString()
	lastName: string;

	@MaxLength(32)
	@IsEmail()
	@IsNotEmpty()
	email: string;

	@IsString()
	@IsNotEmpty()
	@IsStrongPassword({
		minLength: 6,
		minSymbols: 1,
	})
	password: string;
}

export class SignInDto {
	@MaxLength(32)
	@IsEmail()
	@IsNotEmpty()
	email: string;

	@IsString()
	@IsNotEmpty()
	@IsStrongPassword({
		minLength: 6,
		minSymbols: 1,
	})
	password: string;
}
