import { UsersTableInsertSchema } from "src/schema";
import { z } from "zod";

export const SignUpBodySchema = z.object({
	firstName: z.string({ message: "'firstName' should be a string." }).max(24),
	lastName: z.string({ message: "'lastName' should be a string." }).max(24),
	email: z
		.string({ message: "'email' should be a string." })
		.max(32, "'email' should be less than 32 characters")
		.email("Of course 'email' should be an email."),
	password: z
		.string({ message: "'password' should be a string." })
		.min(6)
		//regex for strong password
		.regex(
			/^(?=.*[a-z])(?=.*[A-Z])(?=.*\d)(?=.*[@$!%*?&])[A-Za-z\d@$!%*?&]{6,32}$/,
		)
		.max(32),
});

export const SignInBodySchema = z.object({
	email: z
		.string({ message: "'email' should be a string." })
		.max(32, "'email' should be less than 32 characters")
		.email("Of course 'email' should be an email."),

	password: z
		.string({ message: "'password' should be a string." })
		.min(6)
		.max(32),
});

export const UserUpdateSchema = z.object({
	firstName: z.string({ message: "'firstName' should be a string." }).max(24),

	lastName: z.string({ message: "'lastName' should be a string." }).max(24),
});
