
import { Injectable, OnModuleDestroy, OnModuleInit } from "@nestjs/common";
import { ConfigService } from "@nestjs/config";
import { drizzle } from "drizzle-orm/postgres-js";
import { migrate } from "drizzle-orm/postgres-js/migrator";
import postgres from "postgres";

@Injectable()
export class DrizzleService implements OnModuleInit, OnModuleDestroy {
	private migrationClient: postgres.Sql<Record<string, postgres.PostgresType>>;
	private standardClient: postgres.Sql<Record<string, postgres.PostgresType>>;

	constructor(private configService: ConfigService) {}

	async onModuleInit() {
		const dbConfig = {
			host: this.configService.get<string>("POSTGRES_HOST"),
			port: Number(this.configService.get<string>("POSTGRES_PORT")),
			database: this.configService.get<string>("POSTGRES_DATABASE"),
			user: this.configService.get<string>("POSTGRES_USER"),
			password: this.configService.get<string>("POSTGRES_PASSWORD"),
			ssl: Boolean(this.configService.get<string>("POSTGRES_SSL")),
		};

		this.migrationClient = postgres({
			...dbConfig,
			max: 1,
		});

		this.standardClient = postgres({
			...dbConfig,
		});
	}

	//onModuleDestroy
	async onModuleDestroy() {
		await this.migrationClient.end();
		await this.standardClient.end();
	}

	getMigrationClient() {
		return migrate(drizzle(this.migrationClient), {
			migrationsFolder: "./migrations",
			migrationsSchema: "public",
		});
	}

	use() {
		return drizzle(this.standardClient);
	}
}
