import {
  BadRequestException,
  Body,
  Controller, Delete, Get,
  HttpCode,
  HttpStatus,
  Param,
  Patch,
  Post, Query,
  UseGuards
} from "@nestjs/common";
import { CreateProductDto, EditProductDto } from "src/products/products.dto";
import { AdminGuard } from "src/auth/auth.guard";
import { ProductsService } from "src/products/products.service";

@Controller('products')
export class ProductsController {
  constructor(
    private readonly productsService: ProductsService
  ) {}

  @HttpCode(HttpStatus.CREATED)
  @UseGuards(AdminGuard)
  @Post('add')
  async newProduct(@Body() dto: CreateProductDto) {
    const result = await this.productsService.add(dto)
    if (result.count !== 1) {
      throw new BadRequestException('Insertion failed');
    }
    return result.statement
  }

  @HttpCode(HttpStatus.OK)
  @Get("all")
  async getAllProducts(@Query('page') page: number) {
    return this.productsService.findAll(Number(page) || 1, 2);
  }

  @HttpCode(HttpStatus.OK)
  @UseGuards(AdminGuard)
  @Patch(':id')
  async editProduct(@Param('id') id: string, @Body() dto: EditProductDto) {
    const result = await this.productsService.edit(id, dto);
    if (result.count !== 1) {
      throw new BadRequestException('Update failed');
    }
    return result.statement;
  }

  @HttpCode(HttpStatus.ACCEPTED)
  @UseGuards(AdminGuard)
  @Delete(':id')
  async deleteProduct(@Param('id') id: string) {
    const result = await this.productsService.delete(id);
    if (result.count !== 1) {
      throw new BadRequestException('Deletion failed');
    }
    return result.statement;
  }
}
