import {
  IsEmail, IsInt,
  IsNotEmpty,
  IsString,
  IsStrongPassword,
  MaxLength, Min,
  MinLength
} from "class-validator";
import { optional } from "zod";

export class CreateProductDto {
  @MinLength(1)
  @MaxLength(32)
  @IsNotEmpty()
  @IsString()
  slugName: string;

  @MinLength(1)
  @MaxLength(64)
  @IsNotEmpty()
  @IsString()
  displayName: string;

  @IsInt()
  @Min(0)
  price: number;
}

export class EditProductDto {
  @MinLength(1)
  @MaxLength(32)
  @IsNotEmpty()
  @IsString()
  slugName?: string;

  @MinLength(1)
  @MaxLength(64)
  @IsNotEmpty()
  @IsString()
  displayName?: string;

  @IsInt()
  @Min(0)
  price?: number;
}